@@ -152,6 +152,8 @@ void                    nemo_file_invalidate_attributes             (NemoFile
 									 NemoFileAttributes          attributes);
 void                    nemo_file_invalidate_all_attributes         (NemoFile                   *file);
 
+void                    nemo_file_increment_thumbnail_try_count     (NemoFile                   *file);
+
 /* Basic attributes for file objects. */
 gboolean                nemo_file_contains_text                     (NemoFile                   *file);
 char *                  nemo_file_get_display_name                  (NemoFile                   *file);
@@ -160,6 +162,7 @@ char *                  nemo_file_get_name                          (NemoFile
 GFile *                 nemo_file_get_location                      (NemoFile                   *file);
 char *			 nemo_file_get_description			 (NemoFile			 *file);
 char *                  nemo_file_get_uri                           (NemoFile                   *file);
+char *                  nemo_file_get_path                          (NemoFile                   *file);
 char *                  nemo_file_get_uri_scheme                    (NemoFile                   *file);
 NemoFile *          nemo_file_get_parent                        (NemoFile                   *file);
 GFile *                 nemo_file_get_parent_location               (NemoFile                   *file);
@@ -201,7 +204,8 @@ NemoRequestStatus   nemo_file_get_deep_counts                   (NemoFile
 									 guint                          *directory_count,
 									 guint                          *file_count,
 									 guint                          *unreadable_directory_count,
-									 goffset               *total_size,
+                                     guint                          *hidden_count,
+									 goffset                         *total_size,
 									 gboolean                        force);
 gboolean                nemo_file_should_show_thumbnail             (NemoFile                   *file);
 gboolean                nemo_file_should_show_directory_item_count  (NemoFile                   *file);
@@ -522,6 +526,7 @@ typedef struct {
 							  guint                  *directory_count,
 							  guint                  *file_count,
 							  guint                  *unreadable_directory_count,
+                              guint                  *hidden_count,
 							  goffset       *total_size);
 	gboolean              (* get_date)               (NemoFile           *file,
 							  NemoDateType        type,
