@@ -659,6 +659,12 @@ button_press_callback (GtkWidget *widget, GdkEventButton *event, gpointer callba
 		return FALSE;
 	}
 
+    if (!nemo_view_get_active (NEMO_VIEW (view))) {
+        NemoWindowSlot *slot = nemo_view_get_nemo_window_slot (NEMO_VIEW (view));
+        nemo_window_slot_make_hosting_pane_active (slot);
+        return TRUE;
+    }
+
 	nemo_list_model_set_drag_view
 		(NEMO_LIST_MODEL (gtk_tree_view_get_model (tree_view)),
 		 tree_view,
